@@ -1360,319 +1360,42 @@ sub descend
 # ------------------------------------------------------------
 # metamodel() dispatcher
 # - default (open): DWGN/Interlinear implementation
-# - optional (closed contract): delegated to Sim::OPTcue when enabled
+# - optional (closed treaty): delegated to Sim::OPTcue when enabled
 # ------------------------------------------------------------
 sub metamodel
 {
   my ( $dowhat_r, $sortmixed, $file, $dirfiles_r, $blockelts_r, $carrier_r, $metafile,
     $direction, $starorder, $ordmeta, $varnums_r, $countblock ) = @_;
 
-  my %dowhat = %{ $dowhat_r || {} };
+  my %dowhat = %{ $dowhat_r };
 
   return unless ( defined($dowhat{metamodel}) && $dowhat{metamodel} eq "y" );
 
-  my $contract = "";
-  $contract = $dowhat{metamodelcontract} if defined $dowhat{metamodelcontract};
-  $contract = $dowhat{metamodel_contract} if ( $contract eq "" && defined $dowhat{metamodel_contract} );
+  my $treaty;
+  if ( $dowhat{gometamodel} )
+  {
+    $treaty = $dowhat{gometamodel} ;
+  }
 
-  if ( defined($contract) && $contract eq "cue" )
+  if ( defined( $treaty ) and ( $treaty eq "cue" ) )
   {
     require Sim::OPTcue;
-    return Sim::OPTcue::metamodel_contract(
+    return Sim::OPTcue::gometamodel(
       $dowhat_r, $sortmixed, $file, $dirfiles_r, $blockelts_r, $carrier_r, $metafile,
       $direction, $starorder, $ordmeta, $varnums_r, $countblock
     );
   }
 
-  return _metamodel_dwgn_impl(
+  return( Sim::OPTcue::changemetachannel(
     $dowhat_r, $sortmixed, $file, $dirfiles_r, $blockelts_r, $carrier_r, $metafile,
     $direction, $starorder, $ordmeta, $varnums_r, $countblock
-  );
+  ) );
 }
 
 
 
 
-  sub _metamodel_dwgn_impl
-  {
-    my ( $dowhat_r, $sortmixed, $file, $dirfiles_r, $blockelts_r, $carrier_r, $metafile,
-      $direction, $starorder, $ordmeta, $varnums_r, $countblock ) = @_;
-
-    my %dowhat    = %{ $dowhat_r };
-    my %dirfiles  = %{ $dirfiles_r };
-    my @blockelts = @{ $blockelts_r };
-    my %carrier   = %{ $carrier_r };
-    my %varnums   = %{ $varnums_r };
-
-    return unless ( $dowhat{metamodel} eq "y" );
-
-    # Optional override of the entrance file (for debugging / staging)
-    if ( defined( $dowhat{preprep} ) and ( $dowhat{preprep} ne "" ) )
-    {
-      $sortmixed = $dowhat{preprep};
-      die "PREPREP file not found: $sortmixed\n" unless ( -e $sortmixed );
-    }
-
-    # metamodel() is outside descend(), so do not rely on descend() lexicals
-    my $mypath = $main::mypath;
-    my $tofile = $main::tofile;
-
-    # Interlinear config path (same intent as in descend())
-    my $confinterlinear = $dowhat{confinterlinear};
-    if ( defined( $confinterlinear ) and ( $confinterlinear ne "" ) and defined( $mypath ) and ( $mypath ne "" ) )
-    {
-      $confinterlinear = "$mypath/$confinterlinear";
-    }
-
-    # ---------- helpers as closures (capture lexicals safely) ----------
-
-    my $is_num = sub
-    {
-      my ( $v ) = @_;
-      return 0 unless defined $v;
-      return ( $v =~ /^\s*[-+]?\d*\.?\d+(?:[eE][-+]?\d+)?\s*$/ ) ? 1 : 0;
-    };
-
-    my $canon_id = sub
-    {
-      my ( $id ) = @_;
-      return "" unless defined $id;
-      $id =~ s/\r?\n$//;
-
-      # strip path/file prefix if present
-      if ( defined( $mypath ) and ( $mypath ne "" ) and defined( $file ) and ( $file ne "" ) )
-      {
-        $id =~ s/^\Q$mypath\/$file\E//;
-      }
-
-      # strip leading underscores
-      $id =~ s/^_+//;
-
-      # strip leading "file_" if present
-      if ( defined( $file ) and ( $file ne "" ) )
-      {
-        $id =~ s/^\Q$file\_\E//;
-      }
-      return $id;
-    };
-
-    my $compound_from_fields = sub
-    {
-      my ( $fields_r ) = @_;
-      my @f = @{ $fields_r };
-
-      # last numeric field is the safest definition across both full and short formats
-      for ( my $i = $#f; $i >= 0; $i-- )
-      {
-        if ( $is_num->( $f[$i] ) )
-        {
-          my $v = $f[$i];
-          $v =~ s/^\s+|\s+$//g;
-          return $v;
-        }
-      }
-      return ""; # should never happen for valid formats
-    };
-
-    # ---------- read and clean results (FULL format) ----------
-
-    open( my $IN, "<", $sortmixed ) or die "Cannot open $sortmixed: $!\n";
-    my @raw_full = <$IN>;
-    close $IN;
-
-    my @clean_full;
-    foreach my $ln ( @raw_full )
-    {
-      next unless defined $ln;
-      $ln =~ s/\r?\n$//;
-
-      # preserve the entire row, but canonicalize the ID field reliably
-      my @f = split( /,/, $ln, -1 );
-      next unless scalar( @f ) > 0;
-      $f[0] = $canon_id->( $f[0] );
-
-      my $rebuilt = join( ",", @f );
-      push( @clean_full, $rebuilt );
-    }
-
-    # Optional dump for review
-    if ( defined( $dowhat{dumpfiles} ) and ( $dowhat{dumpfiles} eq "y" ) )
-    {
-      my $cleanordres = $sortmixed . "_tmp_cleaned.csv";
-      open( my $CLEAN, ">", $cleanordres ) or die "Cannot write $cleanordres: $!\n";
-      foreach my $ln ( @clean_full ) { print $CLEAN $ln . "\n"; }
-      close $CLEAN;
-    }
-
-    # ---------- build blanks (IDs only) ----------
-
-    # %varns: for vars not in the block, keep one level only (as in the old pipeline)
-    my %varns = %varnums;
-    foreach my $key ( keys %varns )
-    {
-      if ( not( $key ~~ @blockelts ) )
-      {
-        $varns{$key} = 1;
-      }
-    }
-
-    my $bit = $file . "_";
-    my @bag = ( $bit );
-
-    my @box_refs = @{ Sim::OPT::toil( \@blockelts, \%varns, \@bag ) };
-    my @box      = @{ $box_refs[-1] };
-    my $integrated_r = Sim::OPT::integratebox( \@box, \%carrier, $file, \@blockelts );
-
-    my @blank_ids;
-    foreach my $el ( @{ $integrated_r } )
-    {
-      push( @blank_ids, $canon_id->( $el->[0] ) );
-    }
-    @blank_ids = uniq( @blank_ids );
-
-    if ( defined( $dowhat{dumpfiles} ) and ( $dowhat{dumpfiles} eq "y" ) )
-    {
-      my $blankfile = $sortmixed . "_tmp_blank.csv";
-      open( my $BL, ">", $blankfile ) or die "Cannot write $blankfile: $!\n";
-      foreach my $id ( @blank_ids ) { print $BL $id . "\n"; }
-      close $BL;
-    }
-
-    # ---------- normalize non-block variables (old prepfile logic) ----------
-
-    my %modhs;
-    my %torecovers;
-
-    foreach my $key ( sort keys %varnums )
-    {
-      if ( not( $key ~~ @blockelts ) )
-      {
-        $modhs{$key} = $varnums{$key};
-        $torecovers{$key} = $carrier{$key};
-      }
-    }
-
-    # Apply normalization to blanks
-    my @prep_blanks = @blank_ids;
-    if ( scalar( keys %modhs ) > 0 )
-    {
-      foreach my $id ( @prep_blanks )
-      {
-        foreach my $key ( keys %modhs )
-        {
-          $id =~ s/$key-\d+/$key-$modhs{$key}/;
-        }
-      }
-    }
-
-    # Apply normalization to results
-    my @prep_results = @clean_full;
-    if ( scalar( keys %modhs ) > 0 )
-    {
-      foreach my $ln ( @prep_results )
-      {
-        foreach my $key ( keys %modhs )
-        {
-          $ln =~ s/$key-\d+/$key-$modhs{$key}/;
-        }
-      }
-    }
-
-    if ( defined( $dowhat{dumpfiles} ) and ( $dowhat{dumpfiles} eq "y" ) )
-    {
-      my $prepblank = $sortmixed . "_tmp_prepblank.csv";
-      my $prepsort  = $sortmixed . "_tmp_prepsort.csv";
-      open( my $PB, ">", $prepblank ) or die "Cannot write $prepblank: $!\n";
-      foreach my $id ( @prep_blanks ) { print $PB $id . "\n"; }
-      close $PB;
-      open( my $PS, ">", $prepsort ) or die "Cannot write $prepsort: $!\n";
-      foreach my $ln ( @prep_results ) { print $PS $ln . "\n"; }
-      close $PS;
-    }
-
-    # ---------- join blanks + known values (FULL -> SHORT) in memory ----------
-
-    # Map: id -> compound (from FULL results; compound is last numeric field)
-    my %id2compound;
-    foreach my $ln ( @prep_results )
-    {
-      my @f = split( /,/, $ln, -1 );
-      next unless scalar( @f ) > 1;
-      my $id = $canon_id->( $f[0] );
-      my $compound = $compound_from_fields->( \@f );
-      next if ( $id eq "" );
-      next if ( $compound eq "" );
-      $id2compound{$id} = $compound;
-    }
-
-    # Interlinear input: "id" (unknown) or "id,compound" (known)
-    my @prepfile_lines;
-    foreach my $id ( @prep_blanks )
-    {
-      my $cid = $canon_id->( $id );
-      if ( exists( $id2compound{$cid} ) )
-      {
-        push( @prepfile_lines, $cid . "," . $id2compound{$cid} );
-      }
-      else
-      {
-        push( @prepfile_lines, $cid );
-      }
-    }
-
-    if ( defined( $dowhat{dumpfiles} ) and ( $dowhat{dumpfiles} eq "y" ) )
-    {
-      my $prepfile = $sortmixed . "_tmp_prepfile.csv";
-      open( my $PF, ">", $prepfile ) or die "Cannot write $prepfile: $!\n";
-      foreach my $ln ( @prepfile_lines ) { print $PF $ln . "\n"; }
-      close $PF;
-    }
-
-    # ---------- call Interlinear (arrayref input; you already enabled this) ----------
-
-    my $rawmetafile = $metafile . "_tmp_raw.csv";
-    Sim::OPT::Interlinear::interlinear( \@prepfile_lines, $confinterlinear, $rawmetafile, \@blockelts, $tofile, $countblock, $dowhat_r, $dirfiles_r );
-
-    # ---------- restore non-block variables & write meta outputs ----------
-
-    open( my $RM, "<", $rawmetafile ) or die "Cannot open $rawmetafile: $!\n";
-    my @rawlines = <$RM>;
-    close $RM;
-
-    my @metas;
-    foreach my $ln ( @rawlines )
-    {
-      next unless defined $ln;
-      $ln =~ s/\r?\n$//;
-
-      foreach my $key ( keys %torecovers )
-      {
-        $ln =~ s/$key-\d+/$key-$torecovers{$key}/;
-      }
-      push( @metas, $ln );
-    }
-
-    @metas = uniq( @metas );
-
-    open( my $MF, ">", $metafile ) or die "Cannot write $metafile: $!\n";
-    foreach my $ln ( @metas ) { print $MF $ln . "\n"; }
-    close $MF;
-
-    # Sort and write ORDMETA (overwrite, not append)
-    my @sorted;
-    if ( ( defined( $direction ) and ( $direction eq "<" ) ) or ( defined( $starorder ) and ( $starorder eq "<" ) ) )
-    {
-      @sorted = sort { (split( /,/, $a, -1 ))[1] <=> ( split( /,/, $b, -1 ))[1] } @metas;
-    }
-    else
-    {
-      @sorted = sort { (split( /,/, $b, -1 ))[1] <=> ( split( /,/, $a, -1 ))[1] } @metas;
-    }
-
-    open( my $OM, ">", $ordmeta ) or die "Cannot write $ordmeta: $!\n";
-    foreach my $ln ( @sorted ) { print $OM $ln . "\n"; }
-    close $OM;
-  }  # END SUB metamodel
+  
 
   sub takeoptima
   {
